@@ -62,17 +62,21 @@ class Settings(object):
         if template is None:
             template = os.environ.get("DJANGO_DEBIAN_SETTINGS_TEMPLATE", self.SETTINGS_TEMPLATE)
         if mount_point is None:
-            mount_point = "/{appname}/".format(appname=appname)
+            mount_point = "{appname}/".format(appname=appname)
         else:
             mount_point = mount_point
         self._settings_template = template
         self._appname = appname
         self._settings = self._load_settings()
-        self._mount_point = self._settings.get("MOUNT_POINT", mount_point)
-        # Strip leading slashes, this is required
-        self._mount_point = self._mount_point.lstrip("/")
+        self._mount_point = self._settings.get(
+            "MOUNT_POINT", mount_point
+        ).encode("UTF-8")  # ensure we're still in binary string mode
+        # NOTE: both lines in this order mean that empty mount point stays
+        # empty and root mount point gets sanitized to empty as well.
         # Ensure trailing slash is there
         self._mount_point = self._mount_point.rstrip("/") + "/"
+        # Strip leading slashes, this is required
+        self._mount_point = self._mount_point.lstrip("/")
 
     def _get_pathname(self, filename):
         """
